Module: IiifPrint::WorkShowPresenterDecorator
- Defined in:
- app/presenters/iiif_print/work_show_presenter_decorator.rb
Instance Method Summary collapse
-
#iiif_viewer? ⇒ Boolean
(also: #universal_viewer?)
OVERRIDE Hyrax 2.9.6 to remove check for representative_presenter.image? and allow a fallback to check for images on the child works.
Instance Method Details
#iiif_viewer? ⇒ Boolean Also known as: universal_viewer?
OVERRIDE Hyrax 2.9.6 to remove check for representative_presenter.image? and allow a fallback to check for images on the child works
10 11 12 |
# File 'app/presenters/iiif_print/work_show_presenter_decorator.rb', line 10 def iiif_viewer? parent_work_has_files? || child_work_has_files? end |